@@ -74,6 +74,7 @@ int glp_create_item(int what, char *name)
          }
          row = get_atom(glp->item_pool);
          row->name = row_name;
+         row->kind = 0;
          row->type = GLP_FX;
          row->lb = row->ub = 0.0;
          row->ptr = NULL;
@@ -107,6 +108,7 @@ int glp_create_item(int what, char *name)
          }
          col = get_atom(glp->item_pool);
          col->name = col_name;
+         col->kind = 0;
          col->type = GLP_LO;
          col->lb = col->ub = 0.0;
          col->ptr = NULL;
