@@ -40,8 +40,7 @@
 -- *Description*
 --
 -- The glp_read_mps routine reads LP problem data using MPS format from
--- the text file, whose name is the character string name, into the
--- workspace.
+-- text file whose name is the character string name into the workspace.
 --
 -- As a rule the workspace should be empty before a call to the
 -- glp_read_mps routine, i.e. the workspace should contain no rows and
@@ -125,14 +124,14 @@ int glp_read_mps(char *fname)
          }
       }
       /* set the objective function */
-      glp_set_ipar("obj_dir", GLP_ANY);
+      glp_set_ipar("option", GLP_ANY);
       glp_set_cpar("obj_row", "");
       for (i = 1; i <= m; i++)
       {  row = mps->row[i];
          if (obj[0] == '\0' && strcmp(row->type, "N") == 0 ||
              obj[0] != '\0' && strcmp(row->name, obj) == 0)
          {  strcpy(obj, row->name);
-            glp_set_ipar("obj_dir", GLP_MIN);
+            glp_set_ipar("option", GLP_FIN);
             glp_set_cpar("obj_row", obj);
             break;
          }
