@@ -82,6 +82,9 @@ int glp_set_cpar(char *name, char *val)
             if (node == NULL) return 2; /* row not found */
             glp->obj_row = node->link;
          }
+         /* nullify the constant term, because the objective function
+            has been changed */
+         glp->c0 = 0.0;
       }
       else if (strcmp(name, "problem") == 0)
       {  /* the name of problem */
