@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <float.h>
 #include <math.h>
 #include <stddef.h>
@@ -290,8 +289,8 @@ int gel(MAT *_V, PER *_P, PER *_Q,
          }
          /* piv = v[i,j] = u[p,q] */
          p = iU(piv->i), q = jU(piv->j);
-         assert(k <= p && p <= n && k <= q && q <= n);
-         assert(piv->val != 0.0);
+         insist(k <= p && p <= n && k <= q && q <= n);
+         insist(piv->val != 0.0);
          /* perform implicit permutations of rows and columns of the
             matrix U in order to move the pivot element from u[p,q] to
             u[k,k] */
@@ -365,7 +364,7 @@ static void check_data(void)
       int i, j, nz;
       double big;
       if (!debug) goto skip;
-      assert(1 <= k && k <= n+1);
+      insist(1 <= k && k <= n+1);
       check_mat(V);
       check_per(P);
       check_per(Q);
@@ -375,10 +374,10 @@ static void check_data(void)
          {  /* i-th row of U is placed above the active submatrix */
             for (e = V->row[iV(i)]; e != NULL; e = e->row)
             {  j = jU(e->j);
-               assert(j >= i);
-               assert(e->val != 0.0);
+               insist(j >= i);
+               insist(e->val != 0.0);
             }
-            assert(rs->len[iV(i)] < 0);
+            insist(rs->len[iV(i)] < 0);
          }
          else
          {  /* i-th row of U belongs to the active submatrix */
@@ -386,13 +385,13 @@ static void check_data(void)
             big = 0.0;
             for (e = V->row[iV(i)]; e != NULL; e = e->row)
             {  j = jU(e->j);
-               assert(j >= k);
-               assert(e->val != 0.0);
+               insist(j >= k);
+               insist(e->val != 0.0);
                nz++;
                if (big < fabs(e->val)) big = fabs(e->val);
             }
-            assert(rs->len[iV(i)] == nz);
-            assert(rmax[iV(i)] == big);
+            insist(rs->len[iV(i)] == nz);
+            insist(rmax[iV(i)] == big);
          }
       }
       /* check for columns */
@@ -401,20 +400,20 @@ static void check_data(void)
          {  /* j-th column of U is placed left the active submatrix */
             for (e = V->col[jV(j)]; e != NULL; e = e->col)
             {  i = iU(e->i);
-               assert(i <= j);
-               assert(e->val != 0.0);
+               insist(i <= j);
+               insist(e->val != 0.0);
             }
-            assert(cs->len[jV(j)] < 0);
+            insist(cs->len[jV(j)] < 0);
          }
          else
          {  /* j-th column of U belongs to the active submatrix */
             nz = 0;
             for (e = V->col[jV(j)]; e != NULL; e = e->col)
             {  i = iU(e->i);
-               assert(e->val != 0.0);
+               insist(e->val != 0.0);
                if (i >= k) nz++;
             }
-            assert(cs->len[jV(j)] == nz);
+            insist(cs->len[jV(j)] == nz);
          }
       }
 skip: return;
@@ -491,7 +490,7 @@ static ELEM *find_pivot(void)
 {     ELEM *piv = NULL, *e;
       int i, j, nz;
       double best = DBL_MAX, cost;
-      assert(1 <= k && k <= n);
+      insist(1 <= k && k <= n);
       /* if there is a column containing exactly one non-zero in the
          active submatrix (all such columns are in the list C[1]), the
          corresponding element may be chosen as pivot. */
@@ -503,7 +502,7 @@ static ELEM *find_pivot(void)
             above k-th row), so singlet should be found */
          for (piv = V->col[j]; piv != NULL; piv = piv->col)
             if (iU(piv->i) >= k) break;
-         assert(piv != NULL);
+         insist(piv != NULL);
          goto done;
       }
       /* if there is a row containing exactly one non-zero in the
@@ -514,7 +513,7 @@ static ELEM *find_pivot(void)
       {  /* i-th row contains row singlet (there should be no other
             elements in this row) */
           piv = V->row[i];
-          assert(piv != NULL && piv->row == NULL);
+          insist(piv != NULL && piv->row == NULL);
           goto done;
       }
       /* main loop for searching for pivot */
@@ -548,7 +547,7 @@ static ELEM *find_pivot(void)
             for (e = V->row[i]; e != NULL; e = e->row)
             {  j = e->j;
                /* v[i,j] is always in the active submatrix */
-               assert(jU(j) >= k);
+               insist(jU(j) >= k);
                /* if v[i,j] doesn't satisfy to the numerical stability
                   condition, it should be skipped */
                if (fabs(e->val) < tol * rmax[i]) continue;
@@ -565,8 +564,8 @@ static ELEM *find_pivot(void)
       }
 done: if (piv != NULL)
       {  /* the chosen pivot should be in the active submatrix */
-         assert(k <= iU(piv->i) && iU(piv->i) <= n);
-         assert(k <= jU(piv->j) && jU(piv->j) <= n);
+         insist(k <= iU(piv->i) && iU(piv->i) <= n);
+         insist(k <= jU(piv->j) && jU(piv->j) <= n);
       }
       return piv;
 }
@@ -622,12 +621,12 @@ static void eliminate(ELEM *piv)
 {     ELEM *v, *vn, *e, *en, *ep;
       int i, j, k, p, q, count, nz;
       double f, big, drop = 1e-15;
-      assert(piv != NULL && piv->val != 0.0);
+      insist(piv != NULL && piv->val != 0.0);
       /* determine the pivot v[p,q] = u[k,k] */
       p = piv->i;
       q = piv->j;
       k = iU(p);
-      assert(k == jU(q));
+      insist(k == jU(q));
       /* main elimination loop */
       for (v = V->col[q]; v != NULL; v = v->col)
       {  i = v->i;
@@ -740,7 +739,7 @@ static void eliminate(ELEM *piv)
             else
             {  for (ep = V->col[j]; ep != NULL; ep = ep->col)
                   if (ep->col == e) break;
-               assert(ep != NULL);
+               insist(ep != NULL);
                ep->col = e->col;
             }
             /* return v[i,j] to the memory pool */
