@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
@@ -303,7 +302,7 @@ static int read_card(void)
 
 static int scan_int(char *fld, int pos, int width, int *val)
 {     char str[80+1];
-      assert(1 <= width && width <= 80);
+      insist(1 <= width && width <= 80);
       memcpy(str, card+pos, width), str[width] = '\0';
       if (str2int(strspx(str), val))
       {  error("%s:%d: field `%s' contains invalid value `%s'",
@@ -473,7 +472,7 @@ static int read_real_array(char *name, char *fmt, int n, double val[])
          ptr = strchr(str+1, '+');
          if (ptr == NULL) ptr = strchr(str+1, '-');
          if (ptr != NULL && *(ptr-1) != 'E')
-         {  assert(strlen(str) < 80);
+         {  insist(strlen(str) < 80);
             memmove(ptr+1, ptr, strlen(ptr)+1);
             *ptr = 'E';
          }
