@@ -1,12 +1,12 @@
 /* glpmat/v_solve.c */
 
 /*----------------------------------------------------------------------
--- This file is a part of the GNU LPK package.
+-- This file is a part of the GLPK package.
 --
--- Copyright (C) 2000 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                    Department for Applied Informatics,
---                    Moscow Aviation Institute, Moscow, Russia.
---                    All rights reserved.
+-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
+--                          Department for Applied Informatics,
+--                          Moscow Aviation Institute, Moscow, Russia.
+--                          All rights reserved.
 --
 -- This code is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ double *v_solve(PER *P, MAT *V, PER *Q, double x[], double _work[])
       int i, j, flag = 1;
       double uii, *work = _work;
       if (V->m != V->n)
-         fault("v_solve: matrix is not quadratic");
+         fault("v_solve: matrix is not square");
       if (!(P->n == V->m && Q->n == V->m))
          fault("v_solve: permutation matrices have invalid order");
       if (_work == NULL) work = ucalloc(1+V->m, sizeof(double));
