@@ -72,6 +72,7 @@ LP *mps_to_lp(MPS *mps, char *obj, char *rhs, char *rng, char *bnd)
       MPSROW *row; MPSCOL *col; MPSCQE *cqe; MPSBQE *bqe;
       int m = mps->n_row, n = mps->n_col, i, j, k, objrow, v;
       lp = create_lp(m, n);
+      lp->kind = ucalloc(1+n, sizeof(int));
       /* process ROWS section */
       for (i = 1; i <= m; i++)
       {  k = i; /* x[k] = i-th auxiliary variable */
@@ -96,6 +97,8 @@ LP *mps_to_lp(MPS *mps, char *obj, char *rhs, char *rng, char *bnd)
          /* add column elements to the constraint matrix */
          for (cqe = col->ptr; cqe != NULL; cqe = cqe->next)
             new_elem(lp->A, cqe->ind, j, cqe->val);
+         /* set integer variable flag */
+         lp->kind[j] = (col->flag ? 1 : 0);
       }
       /* determine row of the objective function */
       objrow = 0;
@@ -222,6 +225,16 @@ decr:          lp->lb[k] = lp->ub[k] - fabs(cqe->val);
                lp->lb[k] = -DBL_MAX;
             else if (strcmp(bqe->type, "PL") == 0)
                lp->ub[k] = +DBL_MAX;
+            else if (strcmp(bqe->type, "UI") == 0)
+            {  /* integer structural variable with upper bound */
+               lp->ub[k] = bqe->val;
+               lp->kind[j] = 1;
+            }
+            else if (strcmp(bqe->type, "BV") == 0)
+            {  /* binary structural variable */
+               lp->lb[k] = 0.0, lp->ub[k] = 1.0;
+               lp->kind[j] = 1;
+            }
             else
             {  error("mps_to_lp: bound vector entry for column `%s' has"
                   " unknown type `%s'", col->name, bqe->type);
@@ -241,6 +254,9 @@ decr:          lp->lb[k] = lp->ub[k] - fabs(cqe->val);
                lp->type[k] = 'S';
          }
       }
+      /* if the problem has no integer columns, free the array kind */
+      for (j = 1; j <= n; j++) if (lp->kind[j]) break;
+      if (j > n) ufree(lp->kind), lp->kind = NULL;
       /* return to the calling program */
       return lp;
 fail: /* conversion failed */
