@@ -67,6 +67,18 @@ struct GLPWKSP
       /* --- control parameters segment --- */
       double c0;
       /* the constant term of the objective function */
+      int mip_branch; /* used by MIP solver */
+      /* this parameter specifies what branching technique should be
+         used by the solver:
+         GLP_FIRST - branch on the first integer variable
+         GLP_LAST  - branch on the last integer variable
+         GLP_DRTOM - branch using heuristic by Driebeek and Tomlin */
+      int mip_btrack; /* used by MIP solver */
+      /* this parameter specifies what backtracking technique should be
+         used by the solver:
+         GLP_FIFO  - backtrack using FIFO heuristic
+         GLP_LIFO  - backtrack using LIFO heuristic
+         GLP_BESTP - backtrack using the best projection heuristic */
       char mps_bnd_name[8+1]; /* used by the glp_read_mps routine */
       /* this character string specifies the name of bound vector that
          should be used in the problem; if this parameter is an empty
@@ -92,7 +104,7 @@ struct GLPWKSP
          should be used in the problem; if this parameter is an empty
          string, the first range vector is used */
       int mps_skip_empty; /* used by the glp_write_mps routine */
-      /* if this flag is set, the routine writes all columns, ibcluding
+      /* if this flag is set, the routine writes all columns, including
          empty ones (i.e. those which have no constraint coefficients);
          otherwise the routine write only non-empty columns */
       int mps_use_names; /* used by the glp_write_mps routine */
@@ -101,14 +113,18 @@ struct GLPWKSP
          otherwise the routine generates plain names using sequential
          numbers of rows and columns */
       int obj_dir; /* used by the solver */
-      /* optimization flag:
-         GLP_INI - only initial solution should be found
-         GLP_ANY - only feasible solution should be found
+      /* optimization direction flag:
          GLP_MIN - objective function should be minimized
          GLP_MAX - objective function should be maximized */
       GLPITEM *obj_row; /* used by the solver */
       /* pointer to the objective function row; NULL indicates that the
          objective function is identically equal to zero */
+      int option; /* used by the solver */
+      /* this parameter specifies what solution should be found by the
+         solver:
+         GLP_INI - only initial solution
+         GLP_ANY - any feasible solution
+         GLP_FIN - final solution */
       STR *problem; /* informative */
       /* problem name (1 to 255 chars) */
       int round; /* used by the solver */
@@ -117,7 +133,7 @@ struct GLPWKSP
          solver remains values of all basis variables "as is" */
       int scale; /* used by the solver */
       /* if this flag is set, the solver performs automatic scaling the
-         problem before solving; otherwise the scaling is not used */
+         problem before solving; otherwise scaling is not used */
       int spx_form; /* used by the solver */
       /* this parameter specifies what form of the basis matrix should
          be used by the solver:
@@ -142,8 +158,12 @@ struct GLPWKSP
          GLP_OPT    - solution is optimal
          GLP_FEAS   - soultion is feasible
          GLP_INFEAS - solution is infeasible
-         GLP_NOFEAS - the problem has no feasible solution
-         GLP_UNBND  - the problem has unbounded solution */
+         GLP_NOFEAS - problem has no feasible solution
+         GLP_UNBND  - problem has unbounded solution
+         GLP_INTOPT - solution is integer optimal
+         GLP_INTSOL - solution is integer feasible
+         GLP_DISINT - solution is integer infeasible
+         GLP_NOINT  - problem has no integer feasible solution */
       int sum_aij; /* used by the solver */
       /* if this flag is set, the solver replaces multiplets (i.e.
          elements of the constraint matrix that have identical row and
@@ -162,6 +182,13 @@ struct GLPWKSP
       /* this parameter specifies the relative tolerance which is used
          by the solver for checking dual feasibility of the current
          basis solution */
+      double tol_int; /* used by MIP solver */
+      /* this parameter specifies the absolute tolerance which is used
+         by MIP solver to see if the solution is integer feasible */
+      double tol_obj; /* used by MIP solver */
+      /* this parameter specifies the relative tolerance which is used
+         by MIP solver to see if current value of the objective function
+         is not better than the best integer feasible solution found */
       double tol_piv; /* used by the solver */
       /* this parameter specifies the relative tolerance which is used
          by the solver for pivoting */
@@ -194,11 +221,11 @@ struct GLPITEM
       /* this field is used by GLP routines for different purposes */
       int tagx;
       /* row/column status:
-         GLP_BS - basis variable
-         GLP_NL - non-basis variable on lower bound
-         GLP_NU - non basis variable on upper bound
-         GLP_NF - non-basis free variable
-         GLP_NS - non-basis fixed variable */
+         GLP_BS - basic variable
+         GLP_NL - non-basic variable on lower bound
+         GLP_NU - non basic variable on upper bound
+         GLP_NF - non-basic free variable
+         GLP_NS - non-basic fixed variable */
       double valx;
       /* row/column primal activity */
       double dx;
