@@ -41,10 +41,12 @@
 #define GLP_DB       204   /* double bound:   l[k] <= x[k] <= u[k] */
 #define GLP_FX       205   /* fixed variable: l[k]  = x[k]  = u[k] */
 
-#define GLP_INI      301   /* only initial solution should be found */
-#define GLP_ANY      302   /* only feasible solution should be found */
-#define GLP_MIN      303   /* objective function should be minimized */
-#define GLP_MAX      304   /* objective function should be maximized */
+#define GLP_MIN      301   /* objective function should be minimized */
+#define GLP_MAX      302   /* objective function should be maximized */
+
+#define GLP_INI      311   /* only initial solution is required */
+#define GLP_ANY      312   /* any feasible solution is required */
+#define GLP_FIN      313   /* final solution is required */
 
 #define GLP_UNDEF    401   /* solution is undefined */
 #define GLP_OPT      402   /* solution is optimal */
@@ -52,17 +54,29 @@
 #define GLP_INFEAS   404   /* solution is infeasible */
 #define GLP_NOFEAS   405   /* problem has no feasible solution */
 #define GLP_UNBND    406   /* problem has unbounded solution */
+#define GLP_INTOPT   407   /* solution is integer optimal */
+#define GLP_INTSOL   408   /* solution is integer feasible */
+#define GLP_DISINT   409   /* solution is integer infeasible */
+#define GLP_NOINT    410   /* problem has no integer solution */
 
-#define GLP_BS       501   /* basis variable */
-#define GLP_NL       502   /* non-basis variable on its lower bound */
-#define GLP_NU       503   /* non-basis variable on its upper bound */
-#define GLP_NF       504   /* non-basis free variable */
-#define GLP_NS       505   /* non-basis fixed variable */
+#define GLP_BS       501   /* basic variable */
+#define GLP_NL       502   /* non-basic variable on its lower bound */
+#define GLP_NU       503   /* non-basic variable on its upper bound */
+#define GLP_NF       504   /* non-basic free variable */
+#define GLP_NS       505   /* non-basic fixed variable */
 
 #define GLP_EFI      601   /* EFI */
 #define GLP_RFI_BG   602   /* RFI + Bartels & Golub updating tech */
 #define GLP_RFI_FT   603   /* RFI + Forrest & Tomlin updating tech */
 
+#define GLP_FIRST    701   /* branch on the first variable */
+#define GLP_LAST     702   /* branch on the last variable */
+#define GLP_DRTOM    703   /* branch using Driebeek & Tomlin heur */
+
+#define GLP_FIFO     801   /* backtrack using FIFO strategy */
+#define GLP_LIFO     802   /* backtrack using LIFO strategy */
+#define GLP_BESTP    803   /* backtracj using best projection heur */
+
 #define GLP_D_PARS   0x01  /* dump control parameters */
 #define GLP_D_ROWS   0x10  /* dump rows */
 #define GLP_D_RMAT   0x20  /* dump coefficients for each row */
@@ -119,6 +133,9 @@ extern int glp_get_seqn(int what, int *seqn);
 extern int glp_initialize(void);
 /* initialize GLPK application program interface */
 
+extern int glp_integer(void);
+/* solve MIP problem using branch-and-bound procedure */
+
 extern int glp_interior(void);
 /* solve problem by means of the interior point method */
 
