@@ -38,6 +38,7 @@
 #define load_lpsol            glp_load_lpsol
 #define save_lp               glp_save_lp
 #define save_lpsol            glp_save_lpsol
+#define store_lpsol           glp_store_lpsol
 
 /* the structure LP is a linear programming problem data block which
 -- corresponds to the following problem formulation:
@@ -104,6 +105,12 @@ struct LP
       /* c[0] is the constant term of the objective function; c[j] is
          the coefficient of the objective function at the (structural)
          variable x[m+j] (1 <= j <= n) */
+      int *kind; /* int kind[1+n]; */
+      /* if this field is NULL, the problem is pure LP; otherwise the
+         problem is mixed integer linear programming problem (MIP); in
+         the latter case kind[0] is not used, and kind[j] is a kind of
+         the structural variable x[m+j] (1 <= j <= n): zero means the
+         continuous variable, non-zero means the integer variable */
 };
 
 /* the structure LPSOL is a linear programming problem basis solution
@@ -133,13 +140,16 @@ struct LPSOL
       /* number of rows (auxiliary variables) */
       int n;
       /* number of columns (structural variables) */
+      int mipsol;
+      /* if this flag is zero, the block contains solution of pure LP
+         problem; otherwise it contains solution of MIP problem */
       int status;
       /* solution status:
          '?' - solution is undefined
-         'O' - solution is optimal
-         'F' - solution is feasible
-         'I' - solution is infeasible
-         'N' - problem has no feasible solution
+         'O' - solution is optimal (integer optimal)
+         'F' - solution is feasible (integer feasible)
+         'I' - solution is infeasible (integer infeasible)
+         'N' - problem has no feasible (integer feasible) solution
          'U' - problem has unbounded solution */
       double objval;
       /* value of the objective function */
@@ -190,6 +200,9 @@ extern int save_lp(LP *lp, char *fname);
 extern int save_lpsol(LPSOL *sol, char *fname);
 /* write LP solution to text file using plain format */
 
+extern void store_lpsol(LPSOL *sol);
+/* store LP problem solution into the workspace */
+
 #endif
 
 /* eof */
