@@ -38,7 +38,7 @@
 #define delete_rfi            glp_delete_rfi
 
 /*----------------------------------------------------------------------
--- The structure RFI defines Reid's Form of the Inverse, which is the
+-- The structure RFI defines Reid's Form of the Inverse which is the
 -- following representation of the current basis matrix B:
 --
 --    B = H * V,
@@ -92,7 +92,7 @@ struct RFI
 #define RFI_FT    1  /* Forrest & Tomlin updating technique */
       double *col;
       /* partially transformed column corresponding to that non-basis
-         variable, which has been chosen to enter the basis */
+         variable which has been chosen to enter the basis */
       int flag;
       /* transformed column flag:
          0 - column is not prepared yet
