@@ -27,7 +27,7 @@
 #define _GLPRSM_H
 
 #include "glpefi.h"
-#include "glpmat.h"
+#include "glpprob.h"
 #include "glprfi.h"
 
 #define btran                 glp_btran
@@ -57,6 +57,10 @@
 #define invert_b              glp_invert_b
 #define pivot_col             glp_pivot_col
 #define pivot_row             glp_pivot_row
+#define rsm_dual              glp_rsm_dual
+#define rsm_feas              glp_rsm_feas
+#define rsm_primal            glp_rsm_primal
+#define rsm1_driver           glp_rsm1_driver
 #define update_b              glp_update_b
 #define update_dvec           glp_update_dvec
 #define update_gvec           glp_update_gvec
@@ -232,6 +236,73 @@ extern int harris_col(RSM *rsm, int tagp, double ap[], double c[],
       double cbar[], double tol, double tol1);
 /* choose non-basic variable (dual, Harris technique) */
 
+/*** driver simplex method routines ***/
+
+extern int rsm_primal(RSM *rsm, int (*monit)(void), double c[],
+      double tol_bnd, double tol_dj, double tol_piv, double gvec[],
+      int relax);
+/* find optimal solution using primal simplex method */
+
+extern int rsm_dual(RSM *rsm, int (*monit)(void), double c[],
+      double tol_bnd, double tol_dj, double tol_piv, double dvec[],
+      int relax);
+/* find optimal solution using dual simplex method */
+
+extern int rsm_feas(RSM *rsm, int (*monit)(void),
+      double tol_bnd, double tol_dj, double tol_piv, double gvec[],
+      int relax);
+/* find feasible solution using primal simplex method */
+
+struct rsm1_cp
+{     /* control parameters passed to the rsm1_driver routine */
+      int what;
+      /* this parameter specifies what basis solution should be found
+         by the solver:
+         0 - initial solution
+         1 - primal feasible solution
+         2 - optimal solution */
+      int form;
+      /* this parameter specifies what form of the basis matrix should
+         be used by the solver:
+         0 - EFI
+         1 - RFI + Bartels & Golub updating technique
+         2 - RFI + Forrest & Tomlin updating technique */
+      int scale;
+      /* if this flag is set, the solver performs automatic scaling the
+         problem; otherwise the scaling is not used */
+      int dual;
+      /* if this flag is set, the solver uses the dual simplex method
+         in order to find the primal feasible basis solution; otherwise
+         the solver uses the primal simplex method */
+      int steep;
+      /* if this flag is set, the solver uses the steepest edge pricing
+         (for both primal and dual simplex) proposed by Goldfarb & Reid;
+         otherwise the solver uses the standard "textbook" pricing */
+      int relax;
+      /* if this flag is set, the solver uses two-pass ratio test (for
+         both primal and dual simplex) proposed by P.Harris; otherwise
+         the solver uses the standard "textbook" ratio test */
+      double tol_bnd;
+      /* relative tolerance which is used to see if the solution is
+         primal feasible */
+      double tol_dj;
+      /* relative tolerance which is used to see if the solution is
+         dual feasible */
+      double tol_piv;
+      /* relative tolerance which is used to choose the pivot element
+         of the simplex table */
+      int iter_max;
+      /* maximal allowed number of iterations (0 means no limit) */
+      int round;
+      /* if this flag is set, the solver replaces computed values of
+         basic variables and reduced costs of non-basic variables which
+         are close to zero by exact zeros; otherwise the solver remains
+         all computed values and reduced costs "as is" */
+};
+
+extern int rsm1_driver(LP *lp, LPSOL *sol, struct rsm1_cp *cp);
+/* driver for the revised simplex method */
+
 #endif
 
 /* eof */
